#!/bin/sh

##
# S3/minio setup notes:
# 
# Configure minio - mc alias set ALIAS URL acccess-key-id access-secret
# Configure ojbect expiration - mc ilm add ALIAS/PATH --expire-days 45
#
##

##
# Archive the following:
# * Primary and Events databases
# * Licenses
# * Configuration Files
# * Extra-certificates directory
#
##

DATABASE=/var/lib/spokes/spokes.db
EVENTS_DATABASE=/var/lib/spokes/spokes-events.db
LICENSES=/var/lib/spokes/licenses
CERTS_EXTRA=/var/lib/spokes/certs-extra
CONFIGURATION=/etc/spokes

# temporary files and directories for creating some of the archive artifacts
ARCHIVE_SQL=/tmp/archive.sql
ARCHIVE_DIR=/tmp/spokes-archive-dir

TIMESTAMP=$(date +"%Y-%m-%d_%H:%M:%S")
BACKUP_PRIMARY_DB_FILE=$ARCHIVE_DIR/spokes.db

BACKUP_TARBALL="/tmp/spokes-archive.$TIMESTAMP.tar.gz"

# minio client
MC=/usr/local/bin/mc

# 0. make a fresh archive directory
rm -rf $ARCHIVE_DIR &> /dev/null
mkdir -p $ARCHIVE_DIR

# 1. backup the primary database
echo "PRAGMA journal_mode=wal;
.timeout 60000

.backup $BACKUP_PRIMARY_DB_FILE" > $ARCHIVE_SQL

sqlite3 $DATABASE < $ARCHIVE_SQL 

# 2. backup events
BACKUP_EVENTS_DB_FILE=$ARCHIVE_DIR/spokes-events.db

echo "PRAGMA journal_mode=wal;
.timeout 60000

.backup $BACKUP_EVENTS_DB_FILE" > $ARCHIVE_SQL
sqlite3 $EVENTS_DATABASE < $ARCHIVE_SQL 

# 3. backup licenses
rsync -a $LICENSES $ARCHIVE_DIR

# 4. backup configuration
rsync -a $CONFIGURATION $ARCHIVE_DIR/etc

# 5. create tarball with timestamp
pushd $ARCHIVE_DIR &> /dev/null
tar zcvf "$BACKUP_TARBALL" .
popd &> /dev/null

# 6. archiving the certs extra directory
rsync -a $CERTS_EXTRA $ARCHIVE_DIR

# 7. cleanup
rm -rf $ARCHIVE_SQL $ARCHIVE_DIR &> /dev/null

# 8. copy the file over the S3 to backup for 90 days
TEST_MINIO=$($MC --version)
if [ $? != "0" ]; then
	rm "$BACKUP_TARBALL"
	exit 1
else
	$MC cp -r "$BACKUP_TARBALL" s3/backups/
	rm "$BACKUP_TARBALL"
fi
