#!/bin/bash

TIMESTAMP=$(date +"%Y-%m-%d_%H:%M:%S")

DATABASE_FILE=/var/lib/spokes/spokes.db
BACKUP_DATABASE_FILE=/var/lib/spokes/spokes.db.backup.$TIMESTAMP

BACKUP_SQL_FILE=/usr/share/spokes/db-backup.sql

if [ $(whoami) != "spokes" ]; then
	echo "This script must be run as the 'spokes' user."
	exit 1
fi

systemctl status spokes &> /dev/null
RET_VALUE=$?
if [ "$RET_VALUE" == "0" ]; then
	echo "Spokes should be shutdown prior to running: sudo systemctl stop spokes"
	echo ""
	exit 1
fi

##
# 1. Dump the primary spokes tables into a temporary db file
##
sqlite3 $DATABASE_FILE < $BACKUP_SQL_FILE | grep -v "wal" | sqlite3 $BACKUP_DATABASE_FILE

##
# 2. Rename the existing database to a backup name
##
mv $DATABASE_FILE $DATABASE_FILE.$TIMESTAMP

##
# 3. Rename the backup to use the primary spokes db filename and path
##
mv $BACKUP_DATABASE_FILE $DATABASE_FILE

