// doAPIRequest() is a generic XMLHttpRequest utility that will use a callback
// when available.
//
// callback function should have format - function(object) {} where
// object has the fields:
//   status (boolean)
//   error  (string)
function doAPIRequest(method, url, data, callback) {
	var http = new XMLHttpRequest();
	http.onreadystatechange = function() {
		if (4 != http.readyState) {
			return;
		}

		// No valid callback return immediately.
		if (typeof callback == "undefined" || callback == null) {
			return;
		}

		// Use callback to return status
		try {
			var resp = JSON.parse(http.responseText);
			callback(resp);
		} catch(e) {
			callback({"status": false, "error": "Bad response format from server."});
		}
	}

	http.open(method, url, true);
	http.setRequestHeader("content-type", "application/json");
	http.send(JSON.stringify(data));
}

function isValid(e) {
	if (typeof e == "undefined") {
		return false;
	} else if (e == null) {
		return false;
	}

	return true;
}

function disableElement(event, sender) {
	if (isValid(sender)) {
		sender.setAttribute("disabled", "disabled");
	}
}

function enableElement(e) {
	if (isValid(e)) {
		e.removeAttribute("disabled");
	}
}

function parentWithClass(element, name) {
	if (!isValid(element)) {
		return;
	}

	var t = element;
	while (true) {
		t = t.parentNode;
		if (!isValid(t)) {
			break;
		}

		if (t.className.includes(name)) {
			return t;
		}
	}

	return null;
}

function ShowError(error) {
	// FIXME for now just log to conole but we should flash a message
	// to the user.
	console.log(error);
}

/**
Managing state of VPNs (/admin/vpn)
**/
function ExampleXHR(event, sender) {
	// Create some object...
	var data = {
		id: sender.id
	};
	// Do some other stuff...

	// Execute API request to server.
	doAPIRequest("post", "/api/example", data, function(response) {
		if (typeof response == "undefined" || response == null) {
			return
		} else if (response.status == true) {
			// Do something with response/result from server...
			window.location.reload();
		} else {
			ShowError(response.error);
		}
	});
}

