-- v1.1.0

-- domain table:
--
CREATE TABLE IF NOT EXISTS domain (
    id           BINARY(16) NOT NULL PRIMARY KEY,
    user_id      BINARY(16) NOT NULL,
    created      DATETIME NOT NULL,
    domain_name  VARCHAR(512) NOT NULL
);

CREATE INDEX domain_user_idx ON domain(user_id);
CREATE INDEX domain_name_idx ON domain(domain_name);

-- domain view
--
CREATE VIEW d_domain AS
	SELECT hex(id) AS id, hex(user_id) AS user_id , created, domain_name
	FROM domain;


-- drop the original view
DROP VIEW d_user;

-- rename original user table to something else.
ALTER TABLE user RENAME TO user_archive;

CREATE TABLE IF NOT EXISTS user (
    id                   BINARY(16) NOT NULL PRIMARY KEY,
    created              DATETIME NOT NULL,
    modified             DATETIME,
    last_login           DATETIME,
    last_password_change DATETIME,
    fullname             VARCHAR(128) NOT NULL,
    password             VARCHAR(256) NOT NULL,
    email                VARCHAR(256) NOT NULL,
    phone                VARCHAR(64) NOT NULL,
    admin                SMALLINT DEFAULT 0 NOT NULL,
    active               TINYINT DEFAULT 1 NOT NULL,
    confirmed            TINYINT DEFAULT 0 NOT NULL,
    requires_otp         TINYINT DEFAULT 0 NOT NULL,
    max_bandwidth        INTEGER DEFAULT 0 NOT NULL,
    otp_secret           VARCHAR(64) DEFAULT "" NOT NULL
);

-- create new view
CREATE VIEW d_user AS 
	SELECT hex(id) AS id, created, modified, last_login, last_password_change,
		fullname, password, requires_otp, otp_secret, email, phone, admin, 
		active, confirmed, max_bandwidth
	FROM user;

-- migrate and move the records over.
INSERT INTO user(id, created, modified, last_login, last_password_change, 
	fullname, password, email, phone, admin, active, 
	confirmed, requires_otp, otp_secret)
   		SELECT id, created, modified, last_login, last_password_change, 
			fullname, password, email, phone, admin, active, 
			confirmed, requires_otp, otp_secret FROM user_archive;

-- remove the original (archived) user table.
DROP TABLE user_archive;

