-- v1.2.2

-- software table:
--
CREATE TABLE IF NOT EXISTS software (
    id         BINARY(16) NOT NULL PRIMARY KEY,
    created    DATETIME NOT NULL,
    modified   DATETIME NOT NULL,
    is_latest  TINYINT DEFAULT 0 NOT NULL,
    active     TINYINT DEFAULT 0 NOT NULL,
    file_size  INTEGER DEFAULT 0 NOT NULL,
    version    VARCHAR(24) NOT NULL,
    kind       VARCHAR(24) NOT NULL,
    os         VARCHAR(24) NOT NULL,
    arch       VARCHAR(24) NOT NULL,
    package    VARCHAR(64) NOT NULL,
    hash       VARCHAR(128) NOT NULL,
    file_name  VARCHAR(128) NOT NULL,
    url        VARCHAR(512) NOT NULL
);

CREATE INDEX software_version_idx ON software(version);
CREATE INDEX software_package_idx ON software(package);

-- software view
--
CREATE VIEW d_software AS
	SELECT hex(id) AS id, created, modified, is_latest, active, file_size, 
		package, file_name, version, kind, os, arch, hash, url
	FROM software;


-- tunnel table:
--
-- adding a column is_updated which is used to save whether the client software
-- is running system-installed or an updated released streamed to it.
--
ALTER TABLE tunnel ADD COLUMN is_updated TINYINT DEFAULT 0;

-- update the view for the d_tunnel
DROP VIEW d_tunnel;
CREATE VIEW d_tunnel AS
    SELECT hex(id) AS id, hex(user_id) AS user_id, hex(server_id) AS server_id, 
        created, last_active, is_updated, state, hub_state, uptime, num_https, num_ports, 
        daily, monthly, name, hostname, address
    FROM tunnel;
